@@ -43,12 +43,13 @@ from global_chem.medicinal_chemistry.scaffolds.common_r_group_replacements impor
 # Proteins Kinases
 
 from global_chem.proteins.kinases.braf.braf_inhibitors import BRAFInhibitors
-from global_chem.proteins.kinases.scaffolds.privileged_kinase_inhibtors import PrivilegedKinaseInhibitors
+from global_chem.proteins.kinases.scaffolds.privileged_kinase_inhibitors import PrivilegedKinaseInhibitors
 
 # Organic Synthesis
 
 from global_chem.organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
 from global_chem.organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
+from global_chem.organic_synthesis.bidendate_phosphine_ligands.nickel_ligands import NickelBidendatePhosphineLigands
 
 # Narcotics
 
@@ -63,6 +64,10 @@ from global_chem.narcotics.schedule_five import ScheduleFive
 
 from global_chem.interstellar_space.interstellar_space import InterstellarSpace
 
+# Biopharmaceutics - Excipients
+
+from global_chem.formulation.excipients.biopharmaceutics_class_three.cimetidine_acyclovir import CimetidineAndAcyclovir
+
 # Miscellaneous
 
 from global_chem.miscellaneous.vitamins import Vitamins
@@ -335,7 +340,7 @@ class GlobalChem(object):
         'iupac_blue_book': IUPACBlueBook,                                        # Suliman Sharif
         'common_r_group_replacements': CommonRGroupReplacements,                  # Sunhwan Jo & Suliman Sharif
         'braf_inhibitors': BRAFInhibitors,                                       # Aarion Romany
-        'privileged_kinase_inhibitor_scaffolds': PrivilegedKinaseInhibitors,     # Suliman Sharif
+        'privileged_kinase_inhibitors': PrivilegedKinaseInhibitors,              # Suliman Sharif
         'common_organic_solvents': CommonOrganicSolvents,                        # Suliman Sharif
         'amino_acid_protecting_groups': AminoAcidProtectingGroups,               # Aziza Frank & Suliman Sharif
         'schedule_one': ScheduleOne,                                             # Suliman Sharif
@@ -348,6 +353,8 @@ class GlobalChem(object):
         'open_smiles': OpenSmiles,                                               # Suliman Sharif
         'amino_acids': AminoAcids,                                               # Suliman Sharif
         'pihkal': Pihkal,                                                        # Suliman Sharif
+        'nickel_ligands': NickelBidendatePhosphineLigands,                       # Suliman Sharif
+        'cimetidine_and_acyclovir': CimetidineAndAcyclovir,                      # Suliman Sharif
         'common_regex_patterns': CommonRegexPatterns,                            # Chris Burke & Suliman Sharif
     }
 
@@ -381,7 +388,11 @@ class GlobalChem(object):
 
         '''
 
-        return list(self.__NODES__.values())
+        # Skip the head node
+
+        nodes = [ i() for i in list(self.__NODES__.values())[1:] if i().name != 'common_regex_patterns' ]
+
+        return nodes
 
     def get_node(self, node_key):
 
@@ -1218,4 +1229,29 @@ class GlobalChem(object):
 
         print(PrintTreeUtilities.printTrees(_DEEP_NETWORK_KEY[ self.root_node ]))
 
+    def to_tsv(self, out_file = 'global_chem.tsv'):
+
+
+        '''
+
+        Convert the network into a TSV file in the format:
+
+            IUPAC, SMILES, NODE NAME, TREE PATH
+
+        '''
+
+        out_file = open(out_file, 'w')
+
+        all_nodes = self.get_all_nodes()
+
+        for node in all_nodes:
+
+            node_name = node.name
+            tree_path = node.__module__
+
+            for key, value in node.get_smiles().items():
+
+                out_file.write(f'{key}\t{value}\t{node_name}\t{tree_path}\n')
+
+        out_file.close()
 
